<?php
/**
 * Created by PhpStorm.
 * User: Administrator
 * Date: 18/11/2016
 * Time: 9:18 SA
 */
if ( !class_exists('WC_Product') ) {
    return;
}

if(!class_exists('S7upf_Widget_Product_Categories')) {
    class S7upf_Widget_Product_Categories extends WC_Widget
    {
        static function _init()
        {
            add_action('widgets_init', array(__CLASS__, '_add_widget'));
        }

        static function _add_widget()
        {
            register_widget('S7upf_Widget_Product_Categories');
        }

        /**
         * Constructor.
         */
        public function __construct()
        {
            $this->widget_cssclass = 'woocommerce widget widget-category-icon mb-widget-product-categories';
            $this->widget_description = esc_html__('A list or dropdown of product categories.', 'sport');
            $this->widget_id = 's7upf_product_categories';
            $this->widget_name = esc_html__('S7up Product Categories', 'sport');

            parent::__construct();
        }

        /**
         * Updates a particular instance of a widget.
         *
         * @see WP_Widget->update
         *
         * @param array $new_instance
         * @param array $old_instance
         *
         * @return array
         */
        public function update($new_instance, $old_instance)
        {
            $this->init_settings();

            return parent::update($new_instance, $old_instance);
        }

        public function form($instance)
        {
            $this->init_settings();

            parent::form($instance);
        }

        /**
         * Init settings after post types are registered.
         */
        public function init_settings()
        {

            $category_array = array();
            $tags = get_terms('product_cat');
            if(is_array($tags) && !empty($tags)){
                foreach ($tags as $tag) {
                    $category_array['s7upf_cart_'.$tag->slug]=array(
                        'type' => 'checkbox',
                        'std' => $tag->slug,
                        'label' => $tag->name,
                    );
                }
            }
            $this->settings = array(
                'title'  => array(
                    'type'  => 'text',
                    'std'   => __( 'Product categories', 'sport' ),
                    'label' => __( 'Title', 'sport' ),
                ),
                'orderby' => array(
                    'type'  => 'select',
                    'std'   => 'name',
                    'label' => __( 'Order by', 'sport' ),
                    'options' => array(
                        'order' => __( 'Category order', 'sport' ),
                        'name'  => __( 'Name', 'sport' ),
                        'count-desc'  => __( 'Count DESC', 'sport' ),
                        'count-asc'  => __( 'Count ASC', 'sport' ),
                    ),
                ),
                'count' => array(
                    'type'  => 'checkbox',
                    'std'   => 0,
                    'label' => __( 'Show product counts', 'sport' ),
                ),

                'show_category_icon' => array(
                    'type'  => 'checkbox',
                    'std'   => 0,
                    'label' => __( 'Show category icon', 'sport' ),
                ),

            );
        }

        /**
         * Output widget.
         *
         * @see WP_Widget
         *
         * @param array $args
         * @param array $instance
         */
        public function widget($args, $instance)
        {

            echo wp_kses_post($args['before_widget']);
            if ( ! empty( $instance['title'] ) ) {
                echo wp_kses_post($args['before_title']) . apply_filters( 'widget_title', $instance['title'] ). $args['after_title'];
            }
            extract($instance);
            $orderby  = isset( $instance['orderby'] ) ? $instance['orderby'] : $this->settings['orderby']['std'];
            if($orderby == 'count-desc'){
                $deprecated  = array(
                    'orderby'    => 'count',
                    'order' => 'DESC',
                );
            }else if($orderby == 'count-asc'){
                $deprecated  = array(
                    'orderby'    => 'count',
                    'order' => 'ASC',
                );
            }else{
                $deprecated  = array(
                    'orderby'    => $orderby,
                );
            }

            $terms_cart = get_terms('product_cat',$deprecated);
            ?>
                <div class="list-cat-icon2">
                    <?php if(!empty($terms_cart) and is_array($terms_cart)){
                        ?>
                        <ul class="list-none <?php if(empty($instance['show_category_icon'])) echo 'hide_category_icon'; ?>">
                            <?php foreach ($terms_cart as $tearm){
                                $cart_active = '';
                                if(isset($_GET['product_cat'])) $cart_active = $_GET['product_cat'];
                                if($tearm->slug == $cart_active)
                                    $active = 'active';
                                else $active = '';
                                $icon_image = get_term_meta($tearm->term_id, 'cat-icon-image', true);
                                      //  var_dump($tearm);
                                ?>
                                <li class="<?php if(empty($icon_image) || empty($instance['show_category_icon'])) echo 'no-icon-image'?>">
                                    <a class="<?php echo esc_attr($active); ?>" href="<?php echo esc_url(get_category_link($tearm->term_id))?>">
                                        <?php if(!empty($icon_image) and !empty($instance['show_category_icon'])) { ?>
                                            <img src="<?php echo esc_url($icon_image); ?>" alt="">
                                        <?php } ?>
                                        <?php if(!empty($tearm->name)) echo esc_attr($tearm->name);

                                        if(!empty($instance['count'])) { ?>
                                            <span class="silver">(<?php echo esc_attr($tearm->count); ?>)</span>
                                        <?php } ?>
                                    </a>
                                </li>
                            <?php } ?>
                        </ul>
                    <?php } ?>

                </div>

            <?php
            echo wp_kses_post($args['after_widget']);
        }
    }
    S7upf_Widget_Product_Categories::_init();
}