<?php
/**
 * The template for displaying product content in the single-product.php template
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-single-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @author 		WooThemes
 * @package 	WooCommerce/Templates
 * @version 3.4.0
 */

if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly
}

?>

<?php
/**
 * woocommerce_before_single_product hook.
 *
 * @hooked wc_print_notices - 10
 */
do_action( 'woocommerce_before_single_product' );

if ( post_password_required() ) {
    echo get_the_password_form();
    return;
}
//set number view
s7upf_set_post_view(get_the_ID());
global $product;
$dates_to=$countdown_time=$dates_from_check =$dates_from='';
$rating_count = $product->get_rating_count();
$review_count = $product->get_review_count();

$sale_price_dates_to = get_post_meta(get_the_ID(),'_sale_price_dates_to',true);
$sale_price_dates_from = get_post_meta(get_the_ID(),'_sale_price_dates_from',true);
$number_stock = get_post_meta(get_the_ID(),'_stock',true);

$style_product_detail = s7upf_get_value_by_id('s7upf_style_product_detail');
$availability = $product->get_availability();
?>

<div id="product-<?php the_ID(); ?>" <?php post_class(); ?>>
    <?php
        switch ($style_product_detail){
            case 'style3':?>
                <div class="product-detail s7up-product-detail-<?php echo esc_attr($style_product_detail); ?>">
                    <div class="row">

                        <div class="col-md-3 col-sm-3 col-xs-12">
                            <div class="summary entry-summary summary-left">
                                <h2 class="title-detail title30"><?php the_title(); ?></h2>
                                <ul class="list-inline-block sku-stock">
                                    <?php if ( wc_product_sku_enabled() && ( $product->get_sku() || $product->is_type( 'variable' ) ) ) : ?>
                                        <li class="product_meta"><span class="title14 sku_wrapper"><?php esc_html_e( 'SKU:', 'sport' ); ?></span> <span class="sku"><?php echo ( $sku = $product->get_sku() ) ? $sku : esc_html__( 'N/A', 'sport' ); ?></span></li>
                                    <?php endif; ?>
                                    <?php if( $rating_count > 0 and 'yes' === get_option( 'woocommerce_enable_review_rating' ) ){ ?>
                                        <li>
                                            <?php echo s7upf_get_rating_html();?>
                                            <?php if ( comments_open() ) : ?><a href="#reviews" class="woocommerce-review-link add-review" rel="nofollow"><?php printf( _n( '%s Add your review', '%s Add your reviews', $review_count, 'sport' ), '<span class="number-rate silver">(' . esc_html( $review_count ) . ')</span>' ); ?></a><?php endif ?>

                                        </li>
                                    <?php } ?>
                                    <?php if ( ! empty( $availability['availability'] ) ){ ?>
                                        <li><?php echo wc_get_stock_html($product); ?></li>
                                    <?php } ?>
                                </ul>
                                <div class="product-price">
                                    <?php woocommerce_template_single_price(); ?>
                                </div>

                                <?php

                                $date = getdate();
                                $date = date('Y-m-d H:i:s',$date[0]);
                                if(!empty($sale_price_dates_to)){
                                    $dates_to= date( 'Y-m-d', $sale_price_dates_to );
                                }
                                $date = strtotime($date);
                                $dates_to = strtotime($dates_to);

                                if($dates_to>$date){
                                    $countdown_time = abs($dates_to - $date);
                                }
                                if(!empty($sale_price_dates_from)){
                                    $dates_from= date( 'Y-m-d', $sale_price_dates_from );
                                }
                                $dates_to = strtotime($dates_from);
                                $discount = s7upf_product_loop_discount_sale();
                                if($product->is_type( 'simple' ) || $product->is_type( 'external' )){ ?>
                                    <?php if($product->is_on_sale() and $product->is_in_stock() and $number_stock>0){?>
                                        <p class="percent-config"><span><?php echo esc_attr($discount)?>%</span> <?php echo esc_html__('Off. ','sport'); echo sprintf( esc_html__( 'Hurry, there are only %s item(s) left!', 'sport' ), $number_stock ); ?> </p>
                                    <?php } ?>
                                    <?php if(!empty($countdown_time) and $product->is_on_sale() and $date>$dates_to and $product->is_in_stock()){ ?>
                                        <div class="countdown-product" data-time="<?php echo esc_attr($countdown_time);?>"></div>
                                    <?php }
                                }?>
                                <div class="single_excerpt_product">
                                    <?php woocommerce_template_single_excerpt(); ?>
                                </div>

                            </div>
                        </div>
                        <div class="col-md-6 col-sm-6 col-xs-12">
                            <?php
                            /**
                             * woocommerce_before_single_product_summary hook.
                             *
                             * @hooked woocommerce_show_product_sale_flash - 10
                             * @hooked woocommerce_show_product_images - 20
                             */
                            do_action( 'woocommerce_before_single_product_summary' );
                            ?>
                        </div>
                        <div class="col-md-3 col-sm-3 col-xs-12">
                            <div class="summary entry-summary summary-right">

                                <?php
                                /**
                                 * woocommerce_single_product_summary hook.
                                 *
                                 * @hooked woocommerce_template_single_title - 5
                                 * @hooked woocommerce_template_single_rating - 10
                                 * @hooked woocommerce_template_single_price - 10
                                 * @hooked woocommerce_template_single_excerpt - 20
                                 * @hooked woocommerce_template_single_add_to_cart - 30
                                 * @hooked woocommerce_template_single_meta - 40
                                 * @hooked woocommerce_template_single_sharing - 50
                                 * @hooked WC_Structured_Data::generate_product_data() - 60
                                 */
                                do_action( 'woocommerce_single_product_summary' );
                                ?>

                            </div><!-- .summary -->
                        </div>
                    </div><!-- .row -->
                </div><!-- .product-detail -->
                <?php
                break;
            case 'style2':?>
                <div class="product-detail s7up-product-detail-<?php echo esc_attr($style_product_detail); ?>">
                    <div class="row">
                        <div class="col-md-6 col-sm-6 col-xs-12">
                            <?php
                            /**
                             * woocommerce_before_single_product_summary hook.
                             *
                             * @hooked woocommerce_show_product_sale_flash - 10
                             * @hooked woocommerce_show_product_images - 20
                             */
                            do_action( 'woocommerce_before_single_product_summary' );
                            ?>
                        </div>
                        <div class="col-md-6 col-sm-6 col-xs-12">
                            <div class="summary entry-summary">

                                <?php
                                /**
                                 * woocommerce_single_product_summary hook.
                                 *
                                 * @hooked woocommerce_template_single_title - 5
                                 * @hooked woocommerce_template_single_rating - 10
                                 * @hooked woocommerce_template_single_price - 10
                                 * @hooked woocommerce_template_single_excerpt - 20
                                 * @hooked woocommerce_template_single_add_to_cart - 30
                                 * @hooked woocommerce_template_single_meta - 40
                                 * @hooked woocommerce_template_single_sharing - 50
                                 * @hooked WC_Structured_Data::generate_product_data() - 60
                                 */
                                do_action( 'woocommerce_single_product_summary' );
                                ?>

                            </div><!-- .summary -->
                        </div>
                    </div><!-- .row -->
                </div><!-- .product-detail -->
                <?php
                break;
            default: ?>
                <div class="product-detail s7up-product-detail-<?php echo esc_attr($style_product_detail); ?>">
                    <div class="row">
                        <div class="col-md-7 col-sm-12 col-xs-12">
                            <?php
                            /**
                             * woocommerce_before_single_product_summary hook.
                             *
                             * @hooked woocommerce_show_product_sale_flash - 10
                             * @hooked woocommerce_show_product_images - 20
                             */
                            do_action( 'woocommerce_before_single_product_summary' );
                            ?>
                        </div>
                        <div class="col-md-5 col-sm-12 col-xs-12">
                            <div class="summary entry-summary">

                                <?php
                                /**
                                 * woocommerce_single_product_summary hook.
                                 *
                                 * @hooked woocommerce_template_single_title - 5
                                 * @hooked woocommerce_template_single_rating - 10
                                 * @hooked woocommerce_template_single_price - 10
                                 * @hooked woocommerce_template_single_excerpt - 20
                                 * @hooked woocommerce_template_single_add_to_cart - 30
                                 * @hooked woocommerce_template_single_meta - 40
                                 * @hooked woocommerce_template_single_sharing - 50
                                 * @hooked WC_Structured_Data::generate_product_data() - 60
                                 */
                                do_action( 'woocommerce_single_product_summary' );
                                ?>

                            </div><!-- .summary -->
                        </div>
                    </div><!-- .row -->
                </div><!-- .product-detail -->
                <?php
                break;
        }
    ?>
    <?php
    /**
     * woocommerce_after_single_product_summary hook.
     *
     * @hooked woocommerce_output_product_data_tabs - 10
     * @hooked woocommerce_upsell_display - 15
     * @hooked woocommerce_output_related_products - 20
     */
    do_action( 'woocommerce_after_single_product_summary' );
    ?>

</div><!-- #product-<?php the_ID(); ?> -->

<?php do_action( 'woocommerce_after_single_product' ); ?>
